/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.geoviewer;

import com.vividsolutions.jts.geom.Envelope;
import com.vividsolutions.jts.geom.Point;

/**
 * Defines geographical capabilities for an object.
 * Geographical objects can be displayed on a map.
 * 
 * @author Timon Veenstra
 */
public interface Geographical<O extends Object> {
    
    /**
     * Get the centerpoint for this geographical object.
     * 
     */
    Point getCentroid();
    
    /**
     * Returns an object that is to be rendered on the map/layer valid withing the envelope
     * Can return null if nothing should be rendered within the envelope
     * 
     * @param envelope
     * @return 
     */
    O getRenderObject(Envelope envelope);
    
      /**
     * Get Tooltip text. This can for example be the ID of the wrapped object followed by its name.
     * @return TooltipText as String
     */
    String getTooltipText();

    /**
     * Get the id of the wrapped object.
     * @return The Id of the wrapped object
     */
    long getId();


//    /**
//     * Static helper class for merging specific Geographical actions with the generic Geographical actions
//     */
//    public class Actions {
//        private static final Logger LOG = Logger.getLogger("LayerObject.Actions");
//
//        private Actions(){}
//        
//        /**
//         * Merge the layerobject specific actions with the global layerobject actions
//         *
//         * @param layerObject
//         * @return
//         */
//        public static Action[] mergeActions(Geometrical layerObject) {
//            return mergeActions(layerObject, (Action[]) null);
//        }
//
//        /**
//         * Merge the layerobject specific actions with the global layerobject actions
//         *
//         * @param layerObject
//         * @return
//         */
//        public static Action[] mergeActions(Node node, Action... actions) {
//            // first add all global layer actions from the lookup
//            List<Action> globalActions = new ArrayList<Action>();
//           //
//            // add layer specific actions
//            //
//            GeographicalAction[] specificActions = layerObject.getActions();
//            if (specificActions != null && specificActions.length > 0) {
//                globalActions.addAll(Arrays.asList(specificActions));
//            }
//
//            if (actions != null && actions.length > 0) {
//                globalActions.addAll(Arrays.asList(actions));
//            }
//            return globalActions.toArray(new Action[]{});
//        }
//    }
}
